import aiml
import os
import pkg_resources
import random

class Chatbot:
    STARTUP_FILE = "startup.xml"

    def __init__(self) -> None:
        self.random_response = [
            "Sorry, I can't understand",
            "Can you say that again?",
            "What do you mean?",
            "Hmm",
            "I don't know D:",
            "D:",
            "What?",
            "*thinks*"
        ]

        self.aiml_kernel = aiml.Kernel()
        self.setup_aiml()

    def setup_aiml(self) -> None:
        initial_dir = os.getcwd()
        os.chdir(pkg_resources.resource_filename(__name__, ''))

        # Set default values
        self.aiml_kernel.setBotPredicate("name", "CHAT_BOT_NAME")
        self.aiml_kernel.setBotPredicate("gender", "CHAT_BOT_GENDER")
        self.aiml_kernel.setBotPredicate("age", "CHAT_BOT_AGE")
        self.aiml_kernel.setBotPredicate("master", "CHAT_BOT_MASTER")

        # Load AIML
        self.aiml_kernel.learn(self.STARTUP_FILE)
        self.aiml_kernel.respond("LOAD AIML A")
        self.aiml_kernel.respond("LOAD AIML B")
        os.chdir(initial_dir)

    def get_response(self, message) -> str:
        if not message: return random.choice(self.random_response)

        try:
            response = self.aiml_kernel.respond(message)
            if not response or len(response) < 1: return random.choice(self.random_response)
            return response
            
        except Exception as e:
            return random.choice(self.random_response)



from StarkChat.core import Chatbot
from datetime import datetime

class StarkChat:
    def __init__(self, name="Stark", gender="Male", age=19, birth_year=2004, botmaster="Sathishzus"):
        """Instantiate StarkChat"""

        self.name = name
        self.gender = gender
        self.age = age
        self.birth_year = birth_year
        self.botmaster = botmaster
        self.chatbot = Chatbot()

    def chat(self, message) -> str:
        """Returns a response from the chatbot. If encountered error, returns fallback response"""

        if not message or isinstance(message, str) is False:
            raise TypeError("Message must be a non-empty string")
        else:
            response = self.chatbot.get_response(message=str(message))
            response = response.replace("CHAT_BOT_NAME", self.name)
            response = response.replace("CHAT_BOT_GENDER", self.gender)
            response = response.replace("CHAT_BOT_AGE", str(self.age))
            response = response.replace("CHAT_BOT_MASTER", self.botmaster)
            return response

    def get_age(self) -> int:
        """Returns the age of the chatbot"""

        epoch = self.birth_year
        now = datetime.now().year
        return now - epoch



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['StarkChat']

package_data = \
{'': ['*'], 'StarkChat': ['aiml_data/alice/*', 'aiml_data/custom/*']}

install_requires = \
['python-aiml==0.9.3']

setup_kwargs = {
    'name': 'starkchat',
    'version': '0.0.4',
    'description': 'Stark chatbot client based on AIML',
    'long_description': '# StarkChat\nStark chatbot client based on AIML\n\n# Installation\n\n```sh\npip3 install starkchat\n```\n\n# Example\n\n```py\nfrom StarkChat import starkchat\n\nchatbot = starkchat.StarkChat()\n\nwhile True:\n    question = input("You: ")\n    answer = chatbot.chat(question)\n    print("Bot:", answer)\n```\n\n## Created and maintained by Sathishzus ❄️\n',
    'author': 'Sathishzus',
    'author_email': 'sourechebala19470@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/StarkIndustriesTG',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
